@@ -6,7 +6,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.41';
+our $VERSION = '0.42';
 
 use Courriel::Headers;
 use Courriel::Helpers qw( unique_boundary );
@@ -14,7 +14,7 @@ use Courriel::Part::Multipart;
 use Courriel::Part::Single;
 use Courriel::Types qw( ArrayRef Bool Headers Maybe Part Str StringRef );
 use DateTime;
-use DateTime::Format::Mail;
+use DateTime::Format::Mail 0.403;
 use DateTime::Format::Natural;
 use Email::Address;
 use Encode qw( encode );
@@ -522,13 +522,15 @@ __END__
 
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
 Courriel - High level email parsing and manipulation
 
 =head1 VERSION
 
-version 0.41
+version 0.42
 
 =head1 SYNOPSIS
 
@@ -553,8 +555,6 @@ L<Courriel::Part::Single>, and L<Courriel::Part::Multipart>. If you need lower
 level information about an email, it should be available from one of these
 classes.
 
-=encoding utf-8
-
 =head1 API
 
 This class provides the following methods:
@@ -763,13 +763,6 @@ better than the ones mentioned above.
 This module rips some chunks of code from a few other places, notably several
 of the Email suite modules.
 
-=head1 BUGS
-
-Please report any bugs or feature requests to C<bug-courriel@rt.cpan.org>, or
-through the web interface at L<http://rt.cpan.org>.  I will be notified, and
-then you'll automatically be notified of progress on your bug as I make
-changes.
-
 =head1 DONATIONS
 
 If you'd like to thank me for the work I've done on this module, please
@@ -787,6 +780,35 @@ on free software full time, which seems unlikely at best.
 To donate, log into PayPal and send money to autarch@urth.org or use the
 button on this page: L<http://www.urth.org/~autarch/fs-donation.html>
 
+=head1 BUGS
+
+Please report any bugs or feature requests to C<bug-courriel@rt.cpan.org>, or
+through the web interface at L<http://rt.cpan.org>.  I will be notified, and
+then you'll automatically be notified of progress on your bug as I make
+changes.
+
+Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=Courriel>
+(or L<bug-courriel@rt.cpan.org|mailto:bug-courriel@rt.cpan.org>).
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
+=head1 DONATIONS
+
+If you'd like to thank me for the work I've done on this module, please
+consider making a "donation" to me via PayPal. I spend a lot of free time
+creating free software, and would appreciate any support you'd care to offer.
+
+Please note that B<I am not suggesting that you must do this> in order for me
+to continue working on this particular software. I will continue to do so,
+inasmuch as I have in the past, for as long as it interests me.
+
+Similarly, a donation made in this way will probably not make me work on this
+software much more, unless I get so many donations that I can consider working
+on free software full time (let's all have a chuckle at that together).
+
+To donate, log into PayPal and send money to autarch@urth.org, or use the
+button at L<http://www.urth.org/~autarch/fs-donation.html>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
@@ -811,7 +833,7 @@ Zbigniew Łukasiak <zzbbyy@gmail.com>
 
 =back
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is Copyright (c) 2016 by Dave Rolsky.
 
