@@ -3,7 +3,7 @@ package Courriel::Builder;
 use strict;
 use warnings;
 
-our $VERSION = '0.39';
+our $VERSION = '0.42';
 
 use Carp qw( croak );
 use Courriel;
@@ -453,13 +453,15 @@ __END__
 
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
 Courriel::Builder - Build emails with sugar
 
 =head1 VERSION
 
-version 0.39
+version 0.42
 
 =head1 SYNOPSIS
 
@@ -486,8 +488,6 @@ This module provides some sugar syntax for emails of all shapes sizes, from
 simple emails with a plain text body to emails with both plain and html
 bodies, html with attached images, etc.
 
-=encoding utf-8
-
 =head1 API
 
 This module exports all of the following functions by default. It uses
@@ -713,13 +713,20 @@ This creates an email with this structure:
       |-- application/vnd.ms-excel (disposition = attachment)
       |-- image/png                (disposition = attachment)
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=Courriel>
+(or L<bug-courriel@rt.cpan.org|mailto:bug-courriel@rt.cpan.org>).
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
-This software is Copyright (c) 2015 by Dave Rolsky.
+This software is Copyright (c) 2016 by Dave Rolsky.
 
 This is free software, licensed under:
 
