@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.41';
+our $VERSION = '0.42';
 
 use Courriel::Helpers qw( fold_header );
 use Courriel::Types qw( NonEmptyStr Str Streamable );
@@ -245,13 +245,15 @@ __END__
 
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
 Courriel::Header - A single header's name and value
 
 =head1 VERSION
 
-version 0.41
+version 0.42
 
 =head1 SYNOPSIS
 
@@ -262,8 +264,6 @@ version 0.41
 
 This class represents a single header, which consists of a name and value.
 
-=encoding utf-8
-
 =head1 API
 
 This class supports the following methods:
@@ -302,11 +302,18 @@ See the C<as_string()> method for documentation on the C<charset> parameter.
 
 This class does the C<Courriel::Role::Streams> role.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=Courriel>
+(or L<bug-courriel@rt.cpan.org|mailto:bug-courriel@rt.cpan.org>).
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is Copyright (c) 2016 by Dave Rolsky.
 
