@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.41';
+our $VERSION = '0.42';
 
 use Courriel::Types qw( Maybe NonEmptyStr );
 
@@ -88,13 +88,15 @@ __END__
 
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
 Courriel::Header::ContentType - The content type for an email part
 
 =head1 VERSION
 
-version 0.41
+version 0.42
 
 =head1 SYNOPSIS
 
@@ -121,8 +123,6 @@ Here are some typical headers:
 
   Content-Type: image/jpeg; name="Filename.jpg"
 
-=encoding utf-8
-
 =head1 API
 
 This class supports the following methods:
@@ -225,11 +225,18 @@ This class extends L<Courriel::Header>.
 
 This class does the C<Courriel::Role::HeaderWithAttributes> role.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=Courriel>
+(or L<bug-courriel@rt.cpan.org|mailto:bug-courriel@rt.cpan.org>).
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is Copyright (c) 2016 by Dave Rolsky.
 
