@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.39';
+our $VERSION = '0.42';
 
 use Courriel::Types qw( Bool Maybe NonEmptyStr );
 use DateTime;
@@ -107,13 +107,15 @@ __END__
 
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
 Courriel::Header::Disposition - The content disposition for an email part
 
 =head1 VERSION
 
-version 0.39
+version 0.42
 
 =head1 SYNOPSIS
 
@@ -146,8 +148,6 @@ Here are some typical headers:
   Content-Disposition: attachment; filename="foo-bar.jpg";
     creation-date="Tue, 31 May 2011 09:41:13 -0700"
 
-=encoding utf-8
-
 =head1 API
 
 This class supports the following methods:
@@ -255,13 +255,20 @@ This class extends L<Courriel::Header>.
 
 This class does the C<Courriel::Role::HeaderWithAttributes> role.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=Courriel>
+(or L<bug-courriel@rt.cpan.org|mailto:bug-courriel@rt.cpan.org>).
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
-This software is Copyright (c) 2015 by Dave Rolsky.
+This software is Copyright (c) 2016 by Dave Rolsky.
 
 This is free software, licensed under:
 
