@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.39';
+our $VERSION = '0.42';
 
 use Courriel::HeaderAttribute;
 use Courriel::Helpers qw( unique_boundary );
@@ -114,13 +114,15 @@ __END__
 
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
 Courriel::Part::Multipart - A part which contains other parts
 
 =head1 VERSION
 
-version 0.39
+version 0.42
 
 =head1 SYNOPSIS
 
@@ -133,8 +135,6 @@ version 0.39
 
 This class represents a multipart email part which contains other parts.
 
-=encoding utf-8
-
 =head1 API
 
 This class provides the following methods:
@@ -238,13 +238,20 @@ with "\r\n".
 This class does the C<Courriel::Role::Part> and C<Courriel::Role::Streams>
 roles.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=Courriel>
+(or L<bug-courriel@rt.cpan.org|mailto:bug-courriel@rt.cpan.org>).
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
-This software is Copyright (c) 2015 by Dave Rolsky.
+This software is Copyright (c) 2016 by Dave Rolsky.
 
 This is free software, licensed under:
 
