@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.41';
+our $VERSION = '0.42';
 
 use Courriel::Header::Disposition;
 use Courriel::Types qw( NonEmptyStr StringRef );
@@ -200,13 +200,15 @@ __END__
 
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
 Courriel::Part::Single - A part which does not contain other parts, only content
 
 =head1 VERSION
 
-version 0.41
+version 0.42
 
 =head1 SYNOPSIS
 
@@ -221,8 +223,6 @@ version 0.41
 This class represents a single part that does not contain other parts, just
 content.
 
-=encoding utf-8
-
 =head1 API
 
 This class provides the following methods:
@@ -357,11 +357,18 @@ strings, or via multiple calls to the output.
 This class does the C<Courriel::Role::Part> and C<Courriel::Role::Streams>
 roles.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=Courriel>
+(or L<bug-courriel@rt.cpan.org|mailto:bug-courriel@rt.cpan.org>).
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is Copyright (c) 2016 by Dave Rolsky.
 
