@@ -3,7 +3,7 @@ package Email::Abstract::Courriel;
 use strict;
 use warnings;
 
-our $VERSION = '0.39';
+our $VERSION = '0.42';
 
 use Courriel;
 
@@ -51,32 +51,39 @@ __END__
 
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
 Email::Abstract::Courriel - Email::Abstract wrapper for Courriel
 
 =head1 VERSION
 
-version 0.39
+version 0.42
 
 =head1 DESCRIPTION
 
 This module wraps the Courriel mail handling library with an abstract
 interface, to be used with L<Email::Abstract>.
 
-=encoding utf-8
-
 =head1 SEE ALSO
 
 L<Email::Abstract>, L<Courriel>.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=Courriel>
+(or L<bug-courriel@rt.cpan.org|mailto:bug-courriel@rt.cpan.org>).
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
-This software is Copyright (c) 2015 by Dave Rolsky.
+This software is Copyright (c) 2016 by Dave Rolsky.
 
 This is free software, licensed under:
 
